@@ -3,9 +3,9 @@ from pathlib import Path
 import nox
 
 ROOT = Path(__file__).parent
+PYPROJECT = ROOT / "pyproject.toml"
 DOCS = ROOT / "docs"
 REFERENCING = ROOT / "referencing"
-TESTS = ROOT / "tests"
 
 
 nox.options.sessions = []
@@ -22,22 +22,29 @@ def session(default=True, **kwargs):
 
 @session(python=["3.8", "3.9", "3.10", "3.11", "pypy3"])
 def tests(session):
-    session.install("pytest", str(ROOT))
-    session.run("pytest")
+    dependencies = ["pytest", ROOT]
+    if session.posargs == ["coverage"]:
+        dependencies.append("coverage[toml]")
+        session.install(*dependencies)
+        session.run("coverage", "run", "-m", "pytest")
+        session.run("coverage", "report")
+    else:
+        session.install(*dependencies)
+        session.run("pytest", *session.posargs, REFERENCING)
 
 
 @session(tags=["build"])
 def build(session):
     session.install("build")
     tmpdir = session.create_tmp()
-    session.run("python", "-m", "build", str(ROOT), "--outdir", tmpdir)
+    session.run("python", "-m", "build", ROOT, "--outdir", tmpdir)
 
 
 @session(tags=["style"])
 def readme(session):
     session.install("build", "twine")
     tmpdir = session.create_tmp()
-    session.run("python", "-m", "build", str(ROOT), "--outdir", tmpdir)
+    session.run("python", "-m", "build", ROOT, "--outdir", tmpdir)
     session.run("python", "-m", "twine", "check", tmpdir + "/*")
 
 
@@ -48,28 +55,17 @@ def style(session):
         "flake8-broken-line",
         "flake8-bugbear",
         "flake8-commas",
+        "flake8-docstrings",
         "flake8-quotes",
         "flake8-tidy-imports",
     )
-    session.run(
-        "python",
-        "-m",
-        "flake8",
-        str(REFERENCING),
-        str(TESTS),
-        __file__,
-    )
+    session.run("python", "-m", "flake8", REFERENCING, __file__)
 
 
 @session()
 def typing(session):
-    session.install(  # FIXME: Don't repeat dependencies.
-        "attrs",
-        "mypy",
-        "pyrsistent",
-        str(ROOT),
-    )
-    session.run("python", "-m", "mypy", str(REFERENCING))
+    session.install("pyright", ROOT)
+    session.run("pyright", REFERENCING)
 
 
 @session(tags=["docs"])
@@ -87,7 +83,7 @@ def typing(session):
     ],
 )
 def docs(session, builder):
-    session.install("-r", str(DOCS / "requirements.txt"))
+    session.install("-r", DOCS / "requirements.txt")
     tmpdir = Path(session.create_tmp())
     argv = ["-n", "-T", "-W"]
     if builder != "spelling":
@@ -98,8 +94,8 @@ def docs(session, builder):
         "sphinx",
         "-b",
         builder,
-        str(DOCS),
-        str(tmpdir / builder),
+        DOCS,
+        tmpdir / builder,
         *argv,
     )
 
@@ -111,4 +107,4 @@ def docs_style(session):
         "pygments",
         "pygments-github-lexers",
     )
-    session.run("python", "-m", "doc8", "--max-line-length", "1000", str(DOCS))
+    session.run("python", "-m", "doc8", "--config", PYPROJECT, DOCS)
