@@ -229,6 +229,8 @@ def _maybe_in_subresource(
     in_subvalues: Set[str] = frozenset(),
     in_subarray: Set[str] = frozenset(),
 ):
+    in_child = in_subvalues | in_subarray
+
     def maybe_in_subresource(
         segments: Sequence[int | str],
         resolver: _Resolver[Any],
@@ -236,12 +238,12 @@ def _maybe_in_subresource(
     ) -> _Resolver[Any]:
         _segments = iter(segments)
         for segment in _segments:
-            if segment in in_value:
-                continue
-            elif segment in in_subarray or segment in in_subvalues:
-                if next(_segments, None) is not None:
-                    continue
-            return resolver
+            if (
+                segment not in in_value
+                and segment not in in_child
+                or next(_segments, None) is None
+            ):
+                return resolver
         return resolver.in_subresource(subresource)
 
     return maybe_in_subresource
